import fs from "fs";
import ncp from "ncp";
import chalk from 'chalk';
import { resolve } from "path";
import { promisify } from "util";
const access = promisify(fs.access);
const copy = promisify(ncp);
async function copyTemplatesFiles(options) {
    const { templatesDirectory, targetDirectory } = options;
    return copy(templatesDirectory, targetDirectory, {
        clobber: false,
    });
}
export async function createProject(options) {
    options = {
        ...options,
        targetDirectory: options.targetDirectory || process.cwd()
    };
    const currentFileUrl = import.meta.url;
    const templateDir = resolve(new URL(currentFileUrl).pathname, '../../../templates');
    options.templatesDirectory = templateDir;
    try {
        await access(templateDir, fs.constants.R_OK);
    }
    catch (e) {
        console.error('%s invalid template name', chalk.red.bold('ERROR'));
        process.exit(1);
    }
    console.log('Copy project files');
    await copyTemplatesFiles(options);
    console.log('%s project REady', chalk.green.bold('DONE'));
    return true;
}
//# sourceMappingURL=templates.js.map