import fs from "fs";
import ncp from "ncp";
import chalk from 'chalk';
import { resolve } from "path";
import { promisify } from "util";
import { Arg } from "./arg";

interface Options {
    templatesDirectory: string,
    targetDirectory: string,
    template: string
}

interface ImportMeta {
    url: any
}

const access = promisify(fs.access);
const copy = promisify(ncp);

async function copyTemplatesFiles(options: Arg) {
    const { templatesDirectory, targetDirectory } = options;
    return copy(templatesDirectory, targetDirectory, {
        clobber: false,
    });
}

export async function createProject(options: Arg) {
    options = {
        ...options,
        targetDirectory: options.targetDirectory || process.cwd()
    };
    const currentFileUrl= (import.meta as ImportMeta).url;
    const templateDir = resolve(
        new URL(currentFileUrl).pathname,
        '../../../templates',
    );
    options.templatesDirectory = templateDir;
    try {
        await access(templateDir, fs.constants.R_OK) 
    } catch (e) {
        console.error('%s invalid template name', chalk.red.bold('ERROR'));
        process.exit(1);
    }
    console.log('Copy project files');
    await copyTemplatesFiles(options);
    console.log('%s project REady', chalk.green.bold('DONE'));
    return true;
}
